package discovery

import (
	"github.com/tech/sendico/pkg/model"
	nm "github.com/tech/sendico/pkg/model/notification"
	"github.com/tech/sendico/pkg/mservice"
)

func ServiceAnnounceEvent() model.NotificationEvent {
	return model.NewNotification(mservice.Discovery, nm.NADiscoveryServiceAnnounce)
}

func GatewayAnnounceEvent() model.NotificationEvent {
	return model.NewNotification(mservice.Discovery, nm.NADiscoveryGatewayAnnounce)
}

func HeartbeatEvent() model.NotificationEvent {
	return model.NewNotification(mservice.Discovery, nm.NADiscoveryHeartbeat)
}

func LookupRequestEvent() model.NotificationEvent {
	return model.NewNotification(mservice.Discovery, nm.NADiscoveryLookupRequest)
}

func LookupResponseEvent() model.NotificationEvent {
	return model.NewNotification(mservice.Discovery, nm.NADiscoveryLookupResponse)
}

func RefreshUIEvent() model.NotificationEvent {
	return model.NewNotification(mservice.Discovery, nm.NADiscoveryRefreshUI)
}
